"""A control GUI for Chromecasts"""

# -*- coding: utf-8 -*-

import sys
from cattqt import cattqt

if sys.version_info.major < 3:
    print("This program requires Python 3 and above to run.")
    sys.exit(1)


__author__ = "Scott Moreau"
__email__ = "oreaus@gmail.com"
__version__ = "2.3"


def main() -> None:
    cattqt.main(__version__)



#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['cattqt']

package_data = \
{'': ['*']}

entry_points = \
{'console_scripts': ['catt-qt = cattqt:main']}

setup(name='cattqt',
      version='2.3',
      description='A control GUI for Chromecasts',
      author='Scott Moreau',
      author_email='oreaus@gmail.com',
      url='https://github.com/soreau/catt-qt',
      packages=packages,
      package_data=package_data,
      entry_points=entry_points,
     )
